#[non_exhaustive]pub enum State {
Before(StateEvents),
After(StateEvents),
}Available on crate features
client or server only.Expand description
State changes in a room.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Before(StateEvents)
The state changes between the previous sync and the start of the timeline.
To get the full list of state changes since the previous sync, the state events in
Timeline must be added to these events to update the local state.
To get this variant, use_state_after must be set to false in the Request, which is
the default.
After(StateEvents)
Implementations